@@ -1,7 +1,5 @@
 from urllib import parse
-
 from chaoslib.settings import get_loaded_settings
-
 from pdchaoskit.settings import get_api_url
 
 
@@ -9,22 +7,20 @@ def base():
     return get_api_url(get_loaded_settings())
 
 
-def experiment():
-    return _get_url(
-        base(),
-        'v1/experiments')
+def events():
+    return _get_url(base(), 'v1/events')
 
 
 def executions():
-    return _get_url(
-        base(),
-        'v1/executions')
+    return _get_url(base(), 'v1/executions')
 
 
-def events():
-    return _get_url(
-        base(),
-        'v1/events')
+def experiment():
+    return _get_url(base(), 'v1/experiments')
+
+
+def scripts():
+    return _get_url(base(), 'v1/scripts')
 
 
 def _get_url(base: str, address: str):
